@@ -6,6 +6,10 @@ from ._inspection import HasAttributes, HasName, HasRepr, IsInstance
 from ._numeric import (
     IsApprox,
     IsFloat,
+    IsFloatInf,
+    IsFloatInfNeg,
+    IsFloatInfPos,
+    IsFloatNan,
     IsInt,
     IsNegative,
     IsNegativeFloat,
@@ -18,7 +22,7 @@ from ._numeric import (
     IsPositiveFloat,
     IsPositiveInt,
 )
-from ._other import FunctionCheck, IsIP, IsJson, IsUUID
+from ._other import FunctionCheck, IsHash, IsIP, IsJson, IsUrl, IsUUID
 from ._sequence import Contains, HasLen, IsList, IsListOrTuple, IsTuple
 from ._strings import IsAnyStr, IsBytes, IsStr
 from .version import VERSION
@@ -61,6 +65,10 @@ __all__ = (
     'IsFloat',
     'IsPositiveFloat',
     'IsNegativeFloat',
+    'IsFloatInf',
+    'IsFloatInfNeg',
+    'IsFloatInfPos',
+    'IsFloatNan',
     # inspection
     'HasAttributes',
     'HasName',
@@ -70,6 +78,8 @@ __all__ = (
     'FunctionCheck',
     'IsJson',
     'IsUUID',
+    'IsUrl',
+    'IsHash',
     'IsIP',
     # strings
     'IsStr',
