@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Any, Callable, Container, Dict, Optional, Union, overload
+from typing import Any, Callable, Container, Dict, overload
 
 from ._base import DirtyEquals, DirtyEqualsMeta
 from ._utils import get_dict_arg
@@ -17,14 +17,14 @@ class IsDict(DirtyEquals[Dict[Any, Any]]):
     """
 
     @overload
-    def __init__(self, expected: Dict[Any, Any]):
+    def __init__(self, expected: dict[Any, Any]):
         ...
 
     @overload
     def __init__(self, **expected: Any):
         ...
 
-    def __init__(self, *expected_args: Dict[Any, Any], **expected_kwargs: Any):
+    def __init__(self, *expected_args: dict[Any, Any], **expected_kwargs: Any):
         """
         Can be created from either keyword arguments or an existing dictionary (same as `dict()`).
 
@@ -42,7 +42,7 @@ class IsDict(DirtyEquals[Dict[Any, Any]]):
 
         self.strict = False
         self.partial = False
-        self.ignore: Union[None, Container[Any], Callable[[Any], bool]] = None
+        self.ignore: None | Container[Any] | Callable[[Any], bool] = None
         self._post_init()
         super().__init__()
 
@@ -52,9 +52,9 @@ class IsDict(DirtyEquals[Dict[Any, Any]]):
     def settings(
         self,
         *,
-        strict: Optional[bool] = None,
-        partial: Optional[bool] = None,
-        ignore: Union[None, Container[Any], Callable[[Any], bool]] = NotGiven,  # type: ignore[assignment]
+        strict: bool | None = None,
+        partial: bool | None = None,
+        ignore: None | Container[Any] | Callable[[Any], bool] = NotGiven,  # type: ignore[assignment]
     ) -> IsDict:
         """
         Allows you to customise the behaviour of `IsDict`, technically a new `IsDict` is required to allow chaining.
@@ -70,14 +70,18 @@ class IsDict(DirtyEquals[Dict[Any, Any]]):
         from dirty_equals import IsDict
 
         assert {'a': 1, 'b': 2, 'c': None} != IsDict(a=1, b=2)
-        assert {'a': 1, 'b': 2, 'c': None} == IsDict(a=1, b=2).settings(partial=True) #(1)!
+        assert {'a': 1, 'b': 2, 'c': None} == IsDict(a=1, b=2).settings(partial=True)  # (1)!
 
         assert {'b': 2, 'a': 1} == IsDict(a=1, b=2)
-        assert {'b': 2, 'a': 1} != IsDict(a=1, b=2).settings(strict=True) #(2)!
+        assert {'b': 2, 'a': 1} != IsDict(a=1, b=2).settings(strict=True)  # (2)!
 
         # combining partial and strict
-        assert {'a': 1, 'b': None, 'c': 3} == IsDict(a=1, c=3).settings(strict=True, partial=True)
-        assert {'b': None, 'c': 3, 'a': 1} != IsDict(a=1, c=3).settings(strict=True, partial=True)
+        assert {'a': 1, 'b': None, 'c': 3} == IsDict(a=1, c=3).settings(
+            strict=True, partial=True
+        )
+        assert {'b': None, 'c': 3, 'a': 1} != IsDict(a=1, c=3).settings(
+            strict=True, partial=True
+        )
         ```
 
         1. This is the same as [`IsPartialDict(a=1, b=2)`][dirty_equals.IsPartialDict]
@@ -97,7 +101,7 @@ class IsDict(DirtyEquals[Dict[Any, Any]]):
 
         return new_cls
 
-    def equals(self, other: Dict[Any, Any]) -> bool:
+    def equals(self, other: dict[Any, Any]) -> bool:
         if not isinstance(other, dict):
             return False
 
@@ -117,7 +121,7 @@ class IsDict(DirtyEquals[Dict[Any, Any]]):
 
         return True
 
-    def _filter_dict(self, d: Dict[Any, Any]) -> Dict[Any, Any]:
+    def _filter_dict(self, d: dict[Any, Any]) -> dict[Any, Any]:
         return {k: v for k, v in d.items() if not self._ignore_value(v)}
 
     def _ignore_value(self, v: Any) -> bool:
@@ -188,7 +192,7 @@ class IsIgnoreDict(IsDict):
     from dirty_equals import IsIgnoreDict
 
     assert {'a': 1, 'b': 2, 'c': None} == IsIgnoreDict(a=1, b=2)
-    assert {'a': 1, 'b': 2, 'c': None, 'c': 'ignore'} == (
+    assert {'a': 1, 'b': 2, 'c': 'ignore'} == (
         IsIgnoreDict(a=1, b=2).settings(ignore={None, 'ignore'})
     )
 
